.. highlight:: sh

Installation
============

To install pyrwt you will need the following prerequisites:

* python 2.6+
* numpy
* scipy
* cython

`Python(x,y) <http://code.google.com/p/pythonxy/>`_ is a great way to get all
of these if you are using windows and satisfied with 32bit.

Download the source files of pyrwt. Then, execute::

    $ python setup.py install

You can test the installation by running the examples under the folder ``examples/``

